OC.L10N.register(
    "groupfolders",
    {
    "Unset" : "Non défini",
    "Deny" : "Agwi",
    "Allow" : "Sireg",
    "Group" : "Agraw",
    "Team" : "Tarbaɛt",
    "Read" : "Taɣuri",
    "Create" : "Snulfu-d",
    "Delete" : "Kkes",
    "Share" : "Bḍu",
    "You" : "Kemm·čč",
    "Default" : "Prédéfini(e)",
    "Folder name" : "Isem n ukaram",
    "Previous" : "Ɣer deffir",
    "Next" : "Uḍfir",
    "User" : "Aseqdac",
    "Unknown" : "Arussin",
    "None" : "Ula d yiwen"
},
"nplurals=2; plural=(n != 1);");
